simple_hashtag library

Classes

SimpleHashTag
SimpleHashTag is a package that generates hashtags from strings. By passing a string, a string starting with the specified trigger is hashtagged and returned as RichText.